<?php
// إضافة رؤوس HTTP لمنع التخزين المؤقت
header("Cache-Control: no-cache, no-store, must-revalidate"); // HTTP 1.1
header("Pragma: no-cache"); // HTTP 1.0
header("Expires: 0"); // Proxies

// Path to the target directory
$directory = __DIR__ . "/uploads";

// Number of files displayed per page
$filesPerPage = 5;

// Get the page number from the URL (if not specified, default to page 1)
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;

// Validate the page number to ensure it's a positive integer
if ($page < 1) {
    $page = 1;
}

// Check if the directory exists
if (!is_dir($directory)) {
    die("Directory does not exist.");
}

// Open the directory
if ($handle = opendir($directory)) {
    // Read all files in the directory
    $files = [];
    while (false !== ($file = readdir($handle))) {
        // Skip "." and ".." entries
        if ($file != "." && $file != "..") {
            $filePath = realpath($directory . "/" . $file);

            // Ensure the file is within the allowed directory (prevent directory traversal)
            if (strpos($filePath, realpath($directory)) === 0) {
                $files[] = [
                    'name' => htmlspecialchars($file, ENT_QUOTES, 'UTF-8'), // Sanitize file name
                    'path' => $filePath,
                    'creation_time' => filectime($filePath) // Creation date
                ];
            }
        }
    }
    closedir($handle);

    // Sort files from newest to oldest based on creation time
    usort($files, function ($a, $b) {
        return $b['creation_time'] - $a['creation_time'];
    });

    // Calculate the total number of pages
    $totalFiles = count($files);
    $totalPages = ceil($totalFiles / $filesPerPage);

    // Ensure the page number is within the valid range
    if ($page > $totalPages) {
        $page = $totalPages;
    }

    // Determine the files to display on the current page
    $start = ($page - 1) * $filesPerPage;
    $filesToShow = array_slice($files, $start, $filesPerPage);

    // Start displaying the HTML
    echo "<!DOCTYPE html>
    <html lang='en'>
    <head>
        <meta charset='UTF-8'>
        <meta name='viewport' content='width=device-width, initial-scale=1.0'>
        <meta name='description' content='List of uploaded files'>
        <title>File List</title>
        <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css?version=" . time() . "'>
        <style>
            /* Logo styles */
            .logo-container {
                text-align: center;
                margin: 20px 0;
            }
            .logo-container img {
                width: 150px;
                height: auto;
            }

            /* Button styles */
            .button-container {
                text-align: center;
                margin-bottom: 20px;
            }
            .button-container button {
                background-color: #007BFF;
                color: white;
                border: none;
                padding: 10px 20px;
                margin: 5px;
                cursor: pointer;
                border-radius: 5px;
                font-size: 16px;
                display: inline-block;
            }
            .button-container button:hover {
                background-color: #0056b3;
            }

            /* Table styles */
            table {
                width: auto;
                margin: 20px auto;
                border-collapse: collapse;
            }
            table, th, td {
                border: 1px solid #ddd;
                padding: 8px;
            }
            th {
                background-color: #f2f2f2;
            }
            .pagination {
                text-align: center;
                margin-top: 20px;
            }
            .pagination a {
                margin: 0 5px;
                text-decoration: none;
                color: #007BFF;
            }
            .pagination a.active {
                font-weight: bold;
                color: #000;
            }
        </style>
    </head>
    <body>";

    // إضافة الشعار والأزرار
    echo "
    <div class='logo-container'>
        <img src='images/mbsm.png' alt='MBSM Logo - Secure File Upload Service' width='150'>
    </div>

    <div class='button-container'>
        <button onclick=\"window.location.href='https://mbsm.tn/upload/help.html'\">Help</button>
        <button onclick=\"window.location.href='https://mbsm.tn/upload/'\">Upload</button>
        <button onclick=\"window.open('https://mbsm.tn/', '_blank')\">Mbsm.tn</button>
        <button onclick=\"window.open('https://mbsm.pro/', '_blank')\">Mbsm.pro</button>
        <button onclick=\"window.open('https://mbsm.tn/upload/sitemap.php/', '_blank')\">Sitemap</button>
    </div>";

    // Display the table
    echo "<table>
        <tr><th>File</th><th>Link</th></tr>";

    // Display the files on the current page
    foreach ($filesToShow as $file) {
        $fileUrl = "https://www.mbsm.tn/upload/uploads/" . urlencode($file['name']); // URL-encode file name

        // Determine the icon or thumbnail
        $icon = "fa-file"; // Default icon
        $thumbnail = ""; // Thumbnail
        $extension = strtolower(pathinfo($file['path'], PATHINFO_EXTENSION));

        if (in_array($extension, ['jpg', 'jpeg', 'png', 'gif'])) {
            $icon = "fa-image";
            $thumbnail = "<img src='$fileUrl' alt='{$file['name']}' style='width: 50px; height: auto;'>";
        } elseif ($extension == 'pdf') {
            $icon = "fa-file-pdf";
        } elseif (in_array($extension, ['doc', 'docx'])) {
            $icon = "fa-file-word";
        } elseif (in_array($extension, ['xls', 'xlsx'])) {
            $icon = "fa-file-excel";
        } elseif (in_array($extension, ['zip', 'rar'])) {
            $icon = "fa-file-archive";
        }

        // Display the information in the table
        echo "<tr>
            <td><i class='fas $icon'></i> {$file['name']} $thumbnail</td>
            <td><a href='$fileUrl' target='_blank' rel='noopener noreferrer'>Open File</a></td>
        </tr>";
    }

    echo "</table>";

    // Display pagination
    echo "<div class='pagination'>";
    if ($page > 1) {
        echo "<a href='?page=" . ($page - 1) . "' aria-label='Previous'>&laquo; Previous</a>";
    }
    for ($i = 1; $i <= $totalPages; $i++) {
        if ($i == $page) {
            echo "<a class='active' aria-current='page'>$i</a>";
        } else {
            echo "<a href='?page=$i'>$i</a>";
        }
    }
    if ($page < $totalPages) {
        echo "<a href='?page=" . ($page + 1) . "' aria-label='Next'>Next &raquo;</a>";
    }
    echo "</div>";

    echo "</body>
    </html>";
} else {
    die("Unable to open the directory.");
}
?>